#ifndef VMDA_H_
#define VDMA_H_

#include "xaxivdma.h"

/***************** Macros (Inline Functions) Definitions *********************/
#define RESET_POLL   1000

/**************************** Type Definitions *******************************/
typedef struct vdma_context_t
{
   /* The state variable to keep track if the initialization is done*/
   unsigned int init_done;

   /* The XAxiVdma_DmaSetup structure contains all the necessary information to
    * start a frame write or read. */
   XAxiVdma_DmaSetup ReadCfg;
   XAxiVdma_DmaSetup WriteCfg;
   /* Horizontal size of frame */
   unsigned int hsize;
   /* Vertical size of frame */
   unsigned int vsize;
   /* Buffer address from where read and write will be done by VDMA */
   unsigned int buffer_address;
   /* Flag to tell VDMA to interrupt on frame completion*/
   unsigned int enable_frm_cnt_intr;
   /* The counter to tell VDMA on how many frames the interrupt should happen*/
   unsigned int number_of_frame_count;
} vdma_context_t;



/************************** Variable Definitions *****************************/
/*
 * Device instance definitions
 */
XAxiVdma       AxiVdma;    /**< Instance of AXI Write VMDA core.*/
XAxiVdma       AxiVdma_R;  /**< Instance of AXI Read VMDA core.*/


/************************** Function Prototypes ******************************/
int AxiVDMASelfTestExample(XAxiVdma *InstancePtr, u16 DeviceId);
int resetRead(XAxiVdma *InstancePtr);
int resetWrite(XAxiVdma *InstancePtr);
int configureRead(uint16_t h_res, uint16_t v_res);
int configureWrite(uint16_t h_res, uint16_t v_res);

#endif  /* VDMA_H_ */ 
